BucketQueue

Struct BucketQueue 

pub struct BucketQueue<T, P, C, Q, Storer>
where C: CoarseGrainedPriority<P> + Hash + Ord + Clone, P: Ord, Q: AbstractPriorityQueue<T, P>, Storer: IndexInto<C, Q>,
{ /* private fields */ }
the items of type T and priority P being stored are being stored in one of potentially several Q’s which are all the same kind of AbstractPriorityQueue for such items and priorities but they are divided up by the coarsed grained priority so each one of those are smaller and only storing items with priorities with the same coarse grained priority

Implementations

Source

impl<T, P, C, Q, Storer> BucketQueue<T, P, C, Q, Storer>
where C: CoarseGrainedPriority<P> + Hash + Ord + Clone, P: Ord, Q: AbstractPriorityQueue<T, P>, Storer: IndexInto<C, Q>,

pub fn new( lower_bound_occupied_bucket: C, upper_bound_occupied_bucket: C, dummy: &Q, ) -> Self

pass a lower and upper bound for the coarse grained priorities you are expecting to see these don’t have to be accurate, but if you pass them accurately it is better you also pass an example of Q that is to be used for constructing new buckets